@@ -3,15 +3,14 @@ function (x,...)
 {
 
 require(rgl)
-require(tripack)
 
 
 if(dim(x$data)[2]==2){
 	x11()
 	plot(x$data,asp=1,xlab=expression(data[x]),ylab=expression(data[y]))
-	circles(x=x$center[1,],y=x$center[2,],r=x$radii,col="grey")
+	symbols(x=x$center[1,],y=x$center[2,],circles=x$radii,fg="grey",inches=F,add=T)
 	apply(x$tri,1,function(y) lines(x$data[c(y,y[1]),]))
-	circles(x=x$center[1,x$LiB[[which.max(x$GeB)]]],y=x$center[2,x$LiB[[which.max(x$GeB)]]],r=x$radii[x$LiB[[which.max(x$GeB)]]],col="steelblue2")
+	symbols(x=x$center[1,x$LiB[[which.max(x$GeB)]]],y=x$center[2,x$LiB[[which.max(x$GeB)]]],circles=x$radii[x$LiB[[which.max(x$GeB)]]],fg="steelblue2",inches=F,add=T)
 	apply(x$tri[x$LiB[[which.max(x$GeB)]],],1,function(y) lines(x$data[c(y,y[1]),],col="darkorange"))
 	points(x$data[unique(as.vector(x$tri[x$LiB[[which.max(x$GeB)]],])),],col="red",pch=19)
 	}
